/*-------------------------------------------------------------------
	AXPAD03.H AXP-AD03
	(C) Copyright ADTEK SYSTEM SCIENCE Corp.
-------------------------------------------------------------------*/
#ifndef __AXPAD03_H
#define __AXPAD03_H

#ifdef __cplusplus
extern "C" {
#endif

/* Errors */
#define AD03_SUCCESS                   0   /* Successfully proccessed */
#define AD03_ERR_SYSTEM                1   /* Call GetLastError() */
#define AD03_ERR_NO_DEVICE             2   /* No card */
#define AD03_ERR_IN_USE                3   /* Device is in use */
#define AD03_ERR_INVALID_SOCKET        4   /* Invalid logical Socket */
#define AD03_ERR_RESOURCE              5   /* Resource exhaustion */
#define AD03_ERR_ILLEGAL_FUNCTION_CALL 6   /* Illegal Function Call */
#define AD03_ERR_INVALID_ARGUMENT      7   /* Invalid argument */
#define AD03_ERR_NUMDATA               8   /* Invalid Number of Data */
#define AD03_ERR_INTERNAL              9   /* Internal Error */

/* other */
#define AD03_SOCKET_AUTO     ((WORD) ~0U)  /* I[gT[` */
#define AD03_MAX_SOCKETS              16   /* T|[g\Pbg */
#define AD03_NUM_CHANNELS              2   /* `l */

/* Device ID */
#define AD03_DEVICE_ID                (0x4103UL | (0xc005UL << 16))

/* Message */
#define WM_BUFF_FULL                   0   /* obt@(FIFO)t */
#define WM_CARD_REMOVAL                1   /* J[h */

/* Sampling Status */
#define AD03_STS_SAMPLING           0x01   /* TvO */
#define AD03_STS_BUFF_FULL          0x02   /* obt@(FIFO)t */
#define AD03_STS_HOLDOFF_ERROR      0x04   /* HOLD OFF G[ */

/* Resource infomation structure */
#define	AD03_NMAX_MEM		9
#define	AD03_NMAX_IO		20
#define	AD03_NMAX_IRQ		7
#define	AD03_NMAX_DMA		7

typedef struct _AD03RESOURCE
{
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[AD03_NMAX_MEM];	/* Not used */
	DWORD	dwMemLength		[AD03_NMAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[AD03_NMAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[AD03_NMAX_IO];		/* I/O port base */
	DWORD	dwIOPortLength	[AD03_NMAX_IO];		/* I/O port length */
	DWORD	dwNumIRQs;							/* Num IRQ info */
	DWORD	dwIRQRegisters	[AD03_NMAX_IRQ];	/* IRQ list */
	DWORD	dwIRQAttrib		[AD03_NMAX_IRQ];	/* IRQ Attrib list */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[AD03_NMAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[AD03_NMAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} AD03RESOURCE;

typedef AD03RESOURCE * PAD03R;

/* Mode structure */
typedef struct _AD03MODE
{
	DWORD dwSampleTime;		/* Sampling time */
	DWORD dwTrigMode;		/* Trigger mode */
	DWORD dwTrigSource;		/* Trigger Source */
	DWORD dwTrigSlope;		/* Trigger Slope */
	DWORD dwTrigLevel;		/* Trigger Level */
	DWORD dwTrigPosition;	/* Trigger Position */
	DWORD dwTrigDelay;		/* Trigger Delay time */
	DWORD dwTrigHoldOff;	/* Trigger HoldOff time */
} AD03MODE;

typedef	const AD03MODE * PCAD03M;

#ifndef AD03_API
#define AD03_API

#ifndef AD03_DS
#define AD03_DS	__declspec(dllimport)
#endif

AD03_DS BOOL WINAPI Ad03GetVersion(PDWORD pdwDllVersion, PDWORD pdwVxdVersion);
AD03_DS BOOL WINAPI Ad03Create(PWORD pwLogSocket,HWND hwnd,UINT uWMBase);
AD03_DS BOOL WINAPI Ad01Close(WORD wLogSocket);
AD03_DS BOOL WINAPI Ad01GetResource(WORD wLogSocket,PAD03R pres);
AD03_DS BOOL WINAPI Ad01SetMode(WORD wLogSocket,PCAD03M pcmode);
AD03_DS BOOL WINAPI Ad01StartSampling(WORD wLogSocket);
AD03_DS BOOL WINAPI Ad01StopSampling(WORD wLogSocket);
AD03_DS BOOL WINAPI Ad03GetSamplingStatus(WORD wLogSocket,PDWORD pcwNumData,PDWORD pdwStatus);
AD03_DS BOOL WINAPI Ad03GetData(WORD wLogSocket,DWORD cwNumData,PWORD pwData);
AD03_DS DWORD WINAPI Ad03GetLastError(WORD wLogSocket);

#endif	/* #ifndef AD03_API */

#ifdef __cplusplus
}
#endif

#endif	/* #ifndef __AXPAD03_H */
